package gendarme-csv

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Gendarme_csv.MakeSource

Modular encoder builder

Parameters

module _ : Gendarme.S

Signature

include Gendarme.S
include Gendarme.M
Sourcetype t

The internal encoder type

Sourceval unpack : Gendarme.target -> t

Unpack an internal value

Sourceval pack : t -> Gendarme.target

Pack an internal value

Sourceval marshal : ?v:'a -> 'a Gendarme.ty -> t

Marshal a value

Sourceval unmarshal : ?v:t -> 'a Gendarme.ty -> 'a

Unmarshal a value

Sourceval marshal_safe : ?v:'a -> 'a Gendarme.ty -> t

Marshal a value in an way safe for the encoder

Sourceval unmarshal_safe : ?v:t -> 'a Gendarme.ty -> 'a

Unmarshal a value in a way safe for the encoder

The encoder type representation

Sourceval encode : ?v:'a -> 'a Gendarme.ty -> string

Encode a value into a string representation

Sourceval decode : ?v:string -> 'a Gendarme.ty -> 'a

Decode a value from its string representation